translate.convert.po2html.po2html

Package translate :: Package convert :: Module po2html :: Class po2html |
[hide private]
[frames] | no frames]

# Class po2html

source code

po2html can take a po file and generate html. best to give it a template file otherwise will just concat msgstrs

Instance Methods | [hide private]
lookup(self, string) | source code
mergestore(self, inputstore, templatetext, includefuzzy) converts a file to .po format | source code